==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/pt-pt/generic.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yyyyMMMEd": "E, d/MM/y G",
	"field-second-short": "s",
	"dateTimeFormat-full": "{1} 'às' {0}",
	"dateTimeFormat-short": "{1}, {0}",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-quarter-narrow-relative+-1": "trim. passado",
	"field-sat-short-relative+-1": "sábado passado",
	"field-minute-short": "min",
	"field-mon-short-relative+0": "esta segunda",
	"dateFormatItem-yyyyMMMEEEEd": "EEEE, d/MM/y",
	"field-mon-short-relative+1": "próxima segunda",
	"field-sat-short-relative+0": "este sábado",
	"field-sat-short-relative+1": "próximo sábado",
	"field-quarter-relative+-1": "trimestre passado",
	"field-sun-short-relative+0": "este domingo",
	"field-sun-short-relative+1": "próximo domingo",
	"field-tue-short-relative+0": "esta terça",
	"field-wed-short-relative+0": "esta quarta",
	"field-mon-short-relative+-1": "segunda passada",
	"field-tue-short-relative+1": "próxima terça",
	"field-wed-short-relative+1": "próxima quarta",
	"field-tue-short-relative+-1": "terça passada",
	"dateFormatItem-yyyyQQQQ": "QQQQ 'de' y G",
	"dateTimeFormat-long": "{1} 'às' {0}",
	"dateFormatItem-yyyyMMMd": "d/MM/y G",
	"field-fri-short-relative+-1": "sexta passada",
	"field-quarter-narrow-relative+0": "este trim.",
	"field-quarter-narrow-relative+1": "próximo trim.",
	"field-wed-short-relative+-1": "quarta passada",
	"field-thu-narrow-relative+-1": "qui. passada",
	"field-minute-narrow": "min",
	"field-quarter-short-relative+-1": "trim. passado",
	"field-thu-narrow-relative+0": "esta qui.",
	"dateFormatItem-yyyyQQQ": "QQQQ 'de' y G",
	"field-thu-narrow-relative+1": "próxima qui.",
	"field-thu-short-relative+-1": "quinta passada",
	"dateFormat-short": "d/M/y G",
	"field-quarter-short-relative+0": "este trim.",
	"field-sun-short-relative+-1": "domingo passado",
	"field-quarter-short-relative+1": "próximo trim.",
	"field-fri-short-relative+0": "esta sexta",
	"field-quarter-relative+0": "este trimestre",
	"field-fri-short-relative+1": "próxima sexta",
	"field-quarter-relative+1": "próximo trimestre",
	"dateFormatItem-yyyyMMM": "MM/y G",
	"field-thu-short-relative+0": "esta quinta",
	"field-thu-short-relative+1": "próxima quinta"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/pt-pt/generic.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yyyyMMMEd": "E, d/MM/y G",
	"field-dayperiod": "am/pm",
	"field-second-short": "s",
	"dateTimeFormat-full": "{1} 'às' {0}",
	"dateTimeFormat-short": "{1}, {0}",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-quarter-narrow-relative+-1": "trim. passado",
	"field-sat-short-relative+-1": "sábado passado",
	"field-dayperiod-short": "am/pm",
	"field-minute-short": "min",
	"field-zone-short": "fuso horário",
	"field-mon-short-relative+0": "esta segunda",
	"dateFormatItem-yyyyMMMEEEEd": "EEEE, d/MM/y",
	"field-mon-short-relative+1": "próxima segunda",
	"field-zone-narrow": "fuso horário",
	"field-second-narrow": "s",
	"dateFormat-long": "d 'de' MMMM 'de' y G",
	"field-sat-short-relative+0": "este sábado",
	"field-sat-short-relative+1": "próximo sábado",
	"field-quarter-relative+-1": "trimestre passado",
	"dateFormat-medium": "d MMM y G",
	"field-sun-short-relative+0": "este domingo",
	"field-sun-short-relative+1": "próximo domingo",
	"field-day-short-relative+0": "hoje",
	"field-day-narrow-relative+0": "hoje",
	"field-day-short-relative+1": "amanhã",
	"field-tue-short-relative+0": "esta terça",
	"field-dayperiod-narrow": "am/pm",
	"field-day-narrow-relative+1": "amanhã",
	"field-mon-short-relative+-1": "segunda passada",
	"field-tue-short-relative+1": "próxima terça",
	"field-wed-short-relative+0": "esta quarta",
	"dateFormatItem-yyyyQQQQ": "QQQQ 'de' y G",
	"field-tue-short-relative+-1": "terça passada",
	"field-wed-short-relative+1": "próxima quarta",
	"dateTimeFormat-long": "{1} 'às' {0}",
	"field-day-short-relative+-1": "ontem",
	"dateFormatItem-yyyyMMMd": "d/MM/y G",
	"field-fri-short-relative+-1": "sexta passada",
	"field-quarter-narrow-relative+0": "este trim.",
	"field-quarter-narrow-relative+1": "próximo trim.",
	"field-wed-short-relative+-1": "quarta passada",
	"field-minute-narrow": "min",
	"field-quarter-short-relative+-1": "trim. passado",
	"dateFormatItem-yyyyQQQ": "QQQQ 'de' y G",
	"field-thu-short-relative+-1": "quinta passada",
	"dateFormat-short": "d/M/y G",
	"field-quarter-short-relative+0": "este trim.",
	"field-sun-short-relative+-1": "domingo passado",
	"field-quarter-short-relative+1": "próximo trim.",
	"dateFormat-full": "EEEE, d 'de' MMMM 'de' y G",
	"field-fri-short-relative+0": "esta sexta",
	"field-quarter-relative+0": "este trimestre",
	"field-fri-short-relative+1": "próxima sexta",
	"field-quarter-relative+1": "próximo trimestre",
	"dateFormatItem-yyyyMMM": "MM/y G",
	"field-thu-short-relative+0": "esta quinta",
	"field-thu-short-relative+1": "próxima quinta",
	"field-day-narrow-relative+-1": "ontem"
}
//end v1.x content
);
